remove hacks to disable math or LDG functions.

Этот коммит содержится в:
Ben Sander
2016-04-28 14:14:22 -05:00
родитель 9026146951
Коммит 558975c046
3 изменённых файлов: 1 добавлений и 6 удалений
-3
Просмотреть файл
@@ -21,7 +21,6 @@ THE SOFTWARE.
#define HIP_LDG_H
#if __HCC__
#if defined (USE_LDG)
#include"hip_vector_types.h"
#include"host_defines.h"
#if __hcc_workweek__ >= 16164
@@ -100,8 +99,6 @@ __device__ double4 __ldg(const double4* );
#endif // __hcc_workweek__
#endif // USE_LDG
#endif // __HCC__
#endif // HIP_LDG_H
-2
Просмотреть файл
@@ -109,7 +109,6 @@ extern int HIP_TRACE_API;
#define __HCC_C__
#endif
#ifdef DISABLED_MATH_FUNC // TODO - remove this flag.
__device__ float acosf(float x);
__device__ float acoshf(float x);
__device__ float asinf(float x);
@@ -442,7 +441,6 @@ __device__ float __dsqrt_rd(double x);
__device__ float __dsqrt_rn(double x);
__device__ float __dsqrt_ru(double x);
__device__ float __dsqrt_rz(double x);
#endif /* DISABLED_MATH_FUNC*/
/**
* Kernel launching
*/
+1 -1
Просмотреть файл
@@ -20,7 +20,7 @@ THE SOFTWARE.
#include <hc.hpp>
#include"hcc_detail/hip_ldg.h"
#if __hcc_workweek__ >= 16164 and defined (USE_LDG)
#if __hcc_workweek__ >= 16164
__device__ char __ldg(const char* ptr)
{
return ptr[0];